#!/bin/sh
#   begin_generated_IBM_prolog                                          
#                                                                       
#   prolog.pro.ocol.telcosp                                             
#   ******************************************************************  
#   IBM Licensed Source                                                 
#                                                                       
#   OCO Source Materials                                                
#                                                                       
#   Product(s): 5724-O05                                                
#                                                                       
#   Copyright IBM Corp. 2007, 2007                                      
#                                                                       
#   The source code for this program is restricted to the terms         
#   specified by the End User License Agreement (EULA) that             
#   accompanied this product.                                           
#   ******************************************************************  
#                                                                       
#   end_generated_IBM_prolog                                            

# Usage function
usage ( ) {
	echo "Usage:"
	echo "    $0 <db_name> <db_user> <db_password>"
	echo ""
	echo "Example:"
	echo "    $0 xdms db2inst1 dbpassword"
	echo ""
}

# Check the variables
if [ $# != 3 ]
then
	usage
	exit -1
fi

# Variables
db_name=$1
db_user=$2
db_password=$3

# Create the DB
db2 "create database ${db_name} USING CODESET UTF-8 TERRITORY US COLLATE USING SYSTEM DFT_EXTENT_SZ 64"

# DBM config updates
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING MAXAGENTS 1000"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING SHEAPTHRES 20000"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING MON_HEAP_SZ 512"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING MAX_QUERYDEGREE 1"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING DFT_MON_BUFPOOL off"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING DFT_MON_LOCK off"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING DFT_MON_SORT off"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING DFT_MON_STMT off"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING DFT_MON_TABLE off"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING DFT_MON_TIMESTAMP off"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING DFT_MON_UOW off"
db2 "UPDATE DATABASE MANAGER CONFIGURATION USING HEALTH_MON off"

# DB config updates
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING DBHEAP 8192"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING CATALOGCACHE_SZ 512"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING LOGBUFSZ 2048"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING PCKCACHESZ 2048"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING APPLHEAPSZ 2048"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING APP_CTL_HEAP_SZ 4096"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING STAT_HEAP_SZ 8192"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING STMTHEAP 2048"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING LOGFILSIZ 5000"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING LOGPRIMARY 20"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING LOGSECOND 20"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING MAXAPPLS 500"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING AVG_APPLS 1"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING NUM_IOCLEANERS 3"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING NUM_IOSERVERS 3"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING SOFTMAX 100"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING DFT_DEGREE 1"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING DFT_PREFETCH_SZ 16"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING DFT_EXTENT_SZ 64"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING CHNGPGS_THRESH 60"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING AUTO_MAINT ON"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING AUTO_TBL_MAINT ON"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING AUTO_RUNSTATS ON"
db2 "UPDATE DATABASE CONFIGURATION FOR ${db_name} USING PCKCACHESZ 5000"

# Create the bufferpool, tablespace, and table
db2 "CONNECT TO ${db_name} USER ${db_user} USING ${db_password}"
db2 "create bufferpool BP_4K all nodes size 2000 AUTOMATIC pagesize 4K"
db2 "create bufferpool BP_32K all nodes size 2000 AUTOMATIC pagesize 32K"
db2 "create tablespace IDTS pagesize 4K managed by automatic storage bufferpool BP_4K"
db2 "create tablespace DOCUMENTSTS pagesize 32K managed by automatic storage bufferpool BP_32K"

db2 "drop table accessrules"
db2 "drop table accessrulesacls"
db2 "drop table sharedgroups"
db2 "drop table sharedgroupsacls"
db2 "drop table rlsservices"
db2 "drop table rlsservicesacls"
db2 "drop table resourcelists"
db2 "drop table resourcelistsacls"
db2 "drop table groupusagelist"
db2 "drop table groupusagelistacls"
db2 "drop table userprofile"
db2 "drop table userprofileacls"
db2 "drop table lckduserprofile"
db2 "drop table lckduserprofileacls"
db2 "drop table presrules"
db2 "drop table presrulesacls"
db2 "drop index IDX_LISTSERVICE"

db2 "create table accessrules( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE accessrules ADD CONSTRAINT PK_ACSRULES PRIMARY KEY (id)"
db2 "create table accessrulesacls( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE accessrulesacls ADD CONSTRAINT PK_ACSRULESACL PRIMARY KEY (id)"

db2 "create table sharedgroups( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE sharedgroups ADD CONSTRAINT PK_SHGROUPS PRIMARY KEY (id)"
db2 "CREATE UNIQUE INDEX IDX_LISTSERVICE ON sharedgroups(document) GENERATE KEY USING XMLPATTERN 'declare default element namespace \"urn:oma:xml:poc:list-service\"; /group/list-service/@uri' AS SQL VARCHAR(128)"
db2 "create table sharedgroupsacls( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE sharedgroupsacls ADD CONSTRAINT PK_SHGROUPSACL PRIMARY KEY (id)"

db2 "create table rlsservices( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE rlsservices ADD CONSTRAINT PK_RLSSERIVCES PRIMARY KEY (id)"
db2 "CREATE UNIQUE INDEX IDX_RLSSERVICE ON rlsservices(document) GENERATE KEY USING XMLPATTERN 'declare default element namespace \"urn:ietf:params:xml:ns:rls-services\"; /rls-services/service/@uri' AS SQL VARCHAR(128)"
db2 "create table rlsservicesacls( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE rlsservicesacls ADD CONSTRAINT PK_RLSSERIVACL PRIMARY KEY (id)"

db2 "create table resourcelists( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE resourcelists ADD CONSTRAINT PK_RESOURCELISTS PRIMARY KEY (id)"
db2 "create table resourcelistsacls( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE resourcelistsacls ADD CONSTRAINT PK_RLISTSACL PRIMARY KEY (id)"

db2 "create table groupusagelist( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE groupusagelist ADD CONSTRAINT PK_GROUPUSAGELIST PRIMARY KEY (id)"
db2 "create table groupusagelistacls( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE groupusagelistacls ADD CONSTRAINT PK_GRPUSAGEACL PRIMARY KEY (id)"

db2 "create table userprofile( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE userprofile ADD CONSTRAINT PK_USRPROF PRIMARY KEY (id)"
db2 "create table userprofileacls( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE userprofileacls ADD CONSTRAINT PK_USRPROFACL PRIMARY KEY (id)"

db2 "create table lckduserprofile( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE lckduserprofile ADD CONSTRAINT PK_lckdusrprof PRIMARY KEY (id)"
db2 "create table lckduserprofileacls( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE lckduserprofileacls ADD CONSTRAINT PK_lckdusrprofacl PRIMARY KEY (id)"

db2 "create table presrules( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE presrules ADD CONSTRAINT PK_PRESRULES PRIMARY KEY (id)"
db2 "create table presrulesacls( id varchar(254) not null, create bigint, lastupdate bigint, creator varchar(254), lastupdator varchar(254), document xml) IN IDTS long in DOCUMENTSTS"
db2 "ALTER TABLE presrulesacls ADD CONSTRAINT PK_PRESRULESACLS PRIMARY KEY (id)"

db2stop force
db2start
