#!/bin/sh
#   begin_generated_IBM_prolog                                          
#                                                                       
#   prolog.pro.ocol.telcosp                                             
#   ******************************************************************  
#   IBM Licensed Source                                                 
#                                                                       
#   OCO Source Materials                                                
#                                                                       
#   Product(s): 5724-O05                                                
#                                                                       
#   Copyright IBM Corp. 2007, 2007                                      
#                                                                       
#   The source code for this program is restricted to the terms         
#   specified by the End User License Agreement (EULA) that             
#   accompanied this product.                                           
#   ******************************************************************  
#                                                                       
#   end_generated_IBM_prolog                                            

# Usage function
usage ( ) {
	echo "Usage:"
	echo "    $0 <db_name> <db_user> <db_password>"
	echo ""
	echo "Example:"
	echo "    $0 xdms system passw0rd"
	echo ""
}

# Check the variables
if [ $# != 3 ]
then
	usage
	exit -1
fi

# Variables
db_name=$1
db_user=$2
db_password=$3

#check and handle globals
if [ "$ORACLE_HOME" != "" ] #is ORACLE_HOME set?
then
ORA_HOME=$ORACLE_HOME #apparently 11g is installed, fix ora_home
fi
if [ "$ORA_HOME" = "" ]
then
echo "ORA_HOME / ORACLE_HOME not set."
exit -1 #and thank Oracle for the regress.
fi

# Create the DB
$ORA_HOME/bin/sqlplus /nolog <<+ENDOFSQL+

connect $db_user/$db_password@$db_name

drop table RLSSERVICES;
drop table RLSSERVICESACLS;
drop table RESOURCELISTS;
drop table RESOURCELISTSACLS;
drop table GROUPUSAGELIST;
drop table GROUPUSAGELISTACLS;

drop table SHAREDGROUPS;
drop table SHAREDGROUPSACLS;
drop table ACCESSRULES;
drop table ACCESSRULESACLS;
drop table USERPROFILE;
drop table USERPROFILEACLS;
drop table LCKDUSERPROFILE;
drop table LCKDUSERPROFILEACLS;

drop table UNIQUE_SERVICE_URI;

drop table PRESRULES;
drop table PRESRULESACLS;
drop table UNIQUE_LIST_URI_SG;

drop index RLS_INDEX;
drop index SG_INDEX;

create table RLSSERVICES (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype ) 
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE RLSSERVICES 
	ADD CONSTRAINT PK_RLSSERIVCES 
	PRIMARY KEY ("ID");

create index RLS_INDEX on rlsservices(document) indextype is xdb.xmlindex
	PARAMETERS('PATHS(INCLUDE(/rls-services/service /rls-services/service/resource-list /rls-services/service/@uri)
	namespace mapping(xmlns="urn:ietf:params:xml:ns:rls-services"))
	PATH TABLE RLS_INDEX_TABLE');

create table UNIQUE_SERVICE_URI (
	"URI"	varchar(254) );

ALTER TABLE UNIQUE_SERVICE_URI
	ADD CONSTRAINT URI_UNIQUE
	UNIQUE("URI");


create or replace
TRIGGER TRIGGER_INSERT
BEFORE INSERT ON RLSSERVICES
referencing new as newRow
for each row
BEGIN
insert into unique_service_uri
select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:ietf:params:xml:ns:rls-services' as "ns1"), '/ns1:rls-services/ns1:service'
PASSING :newRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a;
END;
/

create or replace
TRIGGER TRIGGER_UPDATE
BEFORE UPDATE ON RLSSERVICES
referencing new as newRow old as oldRow
for each row
DECLARE
oldDocUri VARCHAR2(254);
BEGIN
delete from unique_service_uri where uri in
(select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:ietf:params:xml:ns:rls-services' as "ns1"), '/ns1:rls-services/ns1:service'
PASSING :oldRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a
);

insert into unique_service_uri
select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:ietf:params:xml:ns:rls-services' as "ns1"), '/ns1:rls-services/ns1:service'
PASSING :newRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a;
END;
/

create or replace
TRIGGER TRIGGER_DELETE
AFTER DELETE ON RLSSERVICES
referencing old as oldRow
for each row
DECLARE
docUri VARCHAR2(254);
BEGIN
delete from unique_service_uri where uri in
(select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:ietf:params:xml:ns:rls-services' as "ns1"), '/ns1:rls-services/ns1:service'
PASSING :oldRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a
);
END;
/

create table RLSSERVICESACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE RLSSERVICESACLS 
	ADD CONSTRAINT PK_RLSSERIVACL 
	PRIMARY KEY ("ID");

create table RESOURCELISTS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE RESOURCELISTS 
	ADD CONSTRAINT PK_RESOURCELISTS 
	PRIMARY KEY ("ID");

create table RESOURCELISTSACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE RESOURCELISTSACLS 
	ADD CONSTRAINT PK_RLISTSACL 
	PRIMARY KEY ("ID");

create table GROUPUSAGELIST (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE GROUPUSAGELIST 
	ADD CONSTRAINT PK_GROUPUSAGELIST 
	PRIMARY KEY ("ID");

create table GROUPUSAGELISTACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE GROUPUSAGELISTACLS 
	ADD CONSTRAINT PK_GRPUSAGEACL 
	PRIMARY KEY ("ID");

	


create table SHAREDGROUPS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE SHAREDGROUPS 
	ADD CONSTRAINT PK_SHGROUPS 
	PRIMARY KEY ("ID");

CREATE INDEX SG_INDEX on SHAREDGROUPS("DOCUMENT")
	INDEXTYPE IS XDB.XMLINDEX
	PARAMETERS ('PATHS (INCLUDE (/group/list-service /group/list-service/@uri)
		namespace mapping(xmlns="urn:oma:xml:poc:list-service"))
		PATH TABLE SG_INDEX_TABLE');

create table UNIQUE_LIST_URI_SG (
	"URI"		varchar(254) );

ALTER TABLE UNIQUE_LIST_URI_SG
	ADD CONSTRAINT URI_UNIQUE_SG
	UNIQUE("URI");

create or replace
TRIGGER TRIGGER_INSERT_SG
BEFORE INSERT ON SHAREDGROUPS
referencing new as newRow
for each row
BEGIN
insert into UNIQUE_LIST_URI_SG
select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:oma:xml:poc:list-service' as "ns1"), '/ns1:group/ns1:list-service'
PASSING :newRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a;
END;
/

create or replace
TRIGGER TRIGGER_UPDATE_SG
BEFORE UPDATE ON SHAREDGROUPS
referencing new as newRow old as oldRow
for each row
DECLARE
oldDocUri VARCHAR2(254);
BEGIN
delete from UNIQUE_LIST_URI_SG where uri in
(select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:oma:xml:poc:list-service' as "ns1"), '/ns1:group/ns1:list-service'
PASSING :oldRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a
);

insert into UNIQUE_LIST_URI_SG
select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:oma:xml:poc:list-service' as "ns1"), '/ns1:group/ns1:list-service'
PASSING :newRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a;
END;
/

create or replace
TRIGGER TRIGGER_DELETE_SG
AFTER DELETE ON SHAREDGROUPS
referencing old as oldRow
for each row
DECLARE
docUri VARCHAR2(254);
BEGIN
delete from UNIQUE_LIST_URI_SG where uri in
(select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:oma:xml:poc:list-service' as "ns1"), '/ns1:group/ns1:list-service'
PASSING :oldRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a
);
END;
/

create table SHAREDGROUPSACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE SHAREDGROUPSACLS 
	ADD CONSTRAINT PK_SHGROUPSACL 
	PRIMARY KEY ("ID");




create table ACCESSRULES (
	"ID" varchar(254) not null, 
	"CREATE" number(19), 
	"LASTUPDATE" number(19), 
	"CREATOR" varchar(254), 
	"LASTUPDATOR" varchar(254), 
	"DOCUMENT" xmltype)
       	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE ACCESSRULES 
	ADD CONSTRAINT PK_ACSRULES 
	PRIMARY KEY ("ID");
	
create table ACCESSRULESACLS (
	"ID" varchar(254) not null, 
	"CREATE" number(19), 
	"LASTUPDATE" number(19), 
	"CREATOR" varchar(254), 
	"LASTUPDATOR" varchar(254), 
	"DOCUMENT" xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE ACCESSRULESACLS 
	ADD CONSTRAINT PK_ACSRULESACL 
	PRIMARY KEY ("ID");




create table USERPROFILE (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE USERPROFILE 
	ADD CONSTRAINT PK_USRPROF 
	PRIMARY KEY ("ID");

create table USERPROFILEACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE USERPROFILEACLS 
	ADD CONSTRAINT PK_USRPROFACL 
	PRIMARY KEY ("ID");

create table LCKDUSERPROFILE (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE LCKDUSERPROFILE 
	ADD CONSTRAINT PK_LCKDUSRPROF 
	PRIMARY KEY ("ID");

create table LCKDUSERPROFILEACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE LCKDUSERPROFILEACLS 
	ADD CONSTRAINT PK_LCKDUSRPROFACL 
	PRIMARY KEY ("ID");





create table PRESRULES(
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE PRESRULES 
	ADD CONSTRAINT PK_PRESRULES 
	PRIMARY KEY ("ID");

create table PRESRULESACLS(
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE PRESRULESACLS 
	ADD CONSTRAINT PK_PRESRULESACLS 
	PRIMARY KEY ("ID");

exit
ENDOFSQL


