#!/bin/sh
#   begin_generated_IBM_prolog                                          
#                                                                       
#   prolog.pro.ocol.telcosp                                             
#   ******************************************************************  
#   IBM Licensed Source                                                 
#                                                                       
#   OCO Source Materials                                                
#                                                                       
#   Product(s): 5724-O05                                                
#                                                                       
#   Copyright IBM Corp. 2007, 2007                                      
#                                                                       
#   The source code for this program is restricted to the terms         
#   specified by the End User License Agreement (EULA) that             
#   accompanied this product.                                           
#   ******************************************************************  
#                                                                       
#   end_generated_IBM_prolog                                            

# Usage function
usage ( ) {
	echo "Usage:"
	echo "    $0 <db_name> <db_user> <db_password>"
	echo ""
	echo "Example:"
	echo "    $0 xdms system passw0rd"
	echo ""
}

# Check the variables
if [ $# != 3 ]
then
	usage
	exit -1
fi

# Variables
db_name=$1
db_user=$2
db_password=$3

#check and handle globals
if [ "$ORACLE_HOME" != "" ] #is ORACLE_HOME set?
then
ORA_HOME=$ORACLE_HOME #apparently 11g is installed, fix ora_home
fi
if [ "$ORA_HOME" = "" ]
then
echo "ORA_HOME / ORACLE_HOME not set."
exit -1 #and thank Oracle for the regress.
fi

# Create the DB
$ORA_HOME/bin/sqlplus /nolog <<+ENDOFSQL+


connect $db_user/$db_password@$db_name

drop table SHAREDGROUPS;
drop table SHAREDGROUPSACLS;
drop table UNIQUE_LIST_URI_SG;

drop index SG_INDEX;

create table SHAREDGROUPS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE SHAREDGROUPS 
	ADD CONSTRAINT PK_SHGROUPS 
	PRIMARY KEY ("ID");

CREATE INDEX SG_INDEX on SHAREDGROUPS("DOCUMENT")
	INDEXTYPE IS XDB.XMLINDEX
	PARAMETERS ('PATHS (INCLUDE (/group/list-service /group/list-service/@uri)
		namespace mapping(xmlns="urn:oma:xml:poc:list-service"))
		PATH TABLE SG_INDEX_TABLE');

create table UNIQUE_LIST_URI_SG (
	"URI"		varchar(254) );

ALTER TABLE UNIQUE_LIST_URI_SG
	ADD CONSTRAINT URI_UNIQUE_SG
	UNIQUE("URI");

create or replace
TRIGGER TRIGGER_INSERT_SG
BEFORE INSERT ON SHAREDGROUPS
referencing new as newRow
for each row
BEGIN
insert into UNIQUE_LIST_URI_SG
select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:oma:xml:poc:list-service' as "ns1"), '/ns1:group/ns1:list-service'
PASSING :newRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a;
END;
/

create or replace
TRIGGER TRIGGER_UPDATE_SG
BEFORE UPDATE ON SHAREDGROUPS
referencing new as newRow old as oldRow
for each row
DECLARE
oldDocUri VARCHAR2(254);
BEGIN
delete from UNIQUE_LIST_URI_SG where uri in
(select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:oma:xml:poc:list-service' as "ns1"), '/ns1:group/ns1:list-service'
PASSING :oldRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a
);

insert into UNIQUE_LIST_URI_SG
select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:oma:xml:poc:list-service' as "ns1"), '/ns1:group/ns1:list-service'
PASSING :newRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a;
END;
/

create or replace
TRIGGER TRIGGER_DELETE_SG
AFTER DELETE ON SHAREDGROUPS
referencing old as oldRow
for each row
DECLARE
docUri VARCHAR2(254);
BEGIN
delete from UNIQUE_LIST_URI_SG where uri in
(select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:oma:xml:poc:list-service' as "ns1"), '/ns1:group/ns1:list-service'
PASSING :oldRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a
);
END;
/

create table SHAREDGROUPSACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE SHAREDGROUPSACLS 
	ADD CONSTRAINT PK_SHGROUPSACL 
	PRIMARY KEY ("ID");

exit
ENDOFSQL


