#!/bin/sh
#   begin_generated_IBM_prolog                                          
#                                                                       
#   prolog.pro.ocol.telcosp                                             
#   ******************************************************************  
#   IBM Licensed Source                                                 
#                                                                       
#   OCO Source Materials                                                
#                                                                       
#   Product(s): 5724-O05                                                
#                                                                       
#   Copyright IBM Corp. 2007, 2007                                      
#                                                                       
#   The source code for this program is restricted to the terms         
#   specified by the End User License Agreement (EULA) that             
#   accompanied this product.                                           
#   ******************************************************************  
#                                                                       
#   end_generated_IBM_prolog                                            

# Usage function
usage ( ) {
	echo "Usage:"
	echo "    $0 <db_name> <db_user> <db_password>"
	echo ""
	echo "Example:"
	echo "    $0 xdms system passw0rd"
	echo ""
}

# Check the variables
if [ $# != 3 ]
then
	usage
	exit -1
fi

# Variables
db_name=$1
db_user=$2
db_password=$3

#check and handle globals
if [ "$ORACLE_HOME" != "" ] #is ORACLE_HOME set?
then
ORA_HOME=$ORACLE_HOME #apparently 11g is installed, fix ora_home
fi
if [ "$ORA_HOME" = "" ]
then
echo "ORA_HOME / ORACLE_HOME not set."
exit -1 #and thank Oracle for the regress.
fi

# Create the DB
$ORA_HOME/bin/sqlplus /nolog <<+ENDOFSQL+


connect $db_user/$db_password@$db_name

drop table RLSSERVICES;
drop table RLSSERVICESACLS;
drop table RESOURCELISTS;
drop table RESOURCELISTSACLS;
drop table GROUPUSAGELIST;
drop table GROUPUSAGELISTACLS;
drop table UNIQUE_SERVICE_URI;

drop index RLS_INDEX;

create table RLSSERVICES (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype ) 
	xmltype column "DOCUMENT" store as binary xml;


ALTER TABLE RLSSERVICES 
	ADD CONSTRAINT PK_RLSSERIVCES 
	PRIMARY KEY ("ID");

create index RLS_INDEX on rlsservices(document) indextype is xdb.xmlindex
	PARAMETERS('PATHS(INCLUDE(/rls-services/service /rls-services/service/resource-list /rls-services/service/@uri)
	namespace mapping(xmlns="urn:ietf:params:xml:ns:rls-services"))
	PATH TABLE RLS_INDEX_TABLE');

create table UNIQUE_SERVICE_URI (
	"URI"	varchar(254) );

ALTER TABLE UNIQUE_SERVICE_URI
	ADD CONSTRAINT URI_UNIQUE
	UNIQUE("URI");


create or replace
TRIGGER TRIGGER_INSERT
BEFORE INSERT ON RLSSERVICES
referencing new as newRow
for each row
BEGIN
insert into unique_service_uri
select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:ietf:params:xml:ns:rls-services' as "ns1"), '/ns1:rls-services/ns1:service'
PASSING :newRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a;
END;
/

create or replace
TRIGGER TRIGGER_UPDATE
BEFORE UPDATE ON RLSSERVICES
referencing new as newRow old as oldRow
for each row
DECLARE
oldDocUri VARCHAR2(254);
BEGIN
delete from unique_service_uri where uri in
(select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:ietf:params:xml:ns:rls-services' as "ns1"), '/ns1:rls-services/ns1:service'
PASSING :oldRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a
);

insert into unique_service_uri
select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:ietf:params:xml:ns:rls-services' as "ns1"), '/ns1:rls-services/ns1:service'
PASSING :newRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a;
END;
/

create or replace
TRIGGER TRIGGER_DELETE
AFTER DELETE ON RLSSERVICES
referencing old as oldRow
for each row
DECLARE
docUri VARCHAR2(254);
BEGIN
delete from unique_service_uri where uri in
(select a.uri from
XMLTABLE(XMLNAMESPACES ('urn:ietf:params:xml:ns:rls-services' as "ns1"), '/ns1:rls-services/ns1:service'
PASSING :oldRow.DOCUMENT
COLUMNS
uri VARCHAR2(254) PATH '@uri')a
);
END;
/

create table RLSSERVICESACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE RLSSERVICESACLS 
	ADD CONSTRAINT PK_RLSSERIVACL 
	PRIMARY KEY ("ID");

create table RESOURCELISTS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE RESOURCELISTS 
	ADD CONSTRAINT PK_RESOURCELISTS 
	PRIMARY KEY ("ID");

create table RESOURCELISTSACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE RESOURCELISTSACLS 
	ADD CONSTRAINT PK_RLISTSACL 
	PRIMARY KEY ("ID");

create table GROUPUSAGELIST (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE GROUPUSAGELIST 
	ADD CONSTRAINT PK_GROUPUSAGELIST 
	PRIMARY KEY ("ID");

create table GROUPUSAGELISTACLS (
	"ID" 		varchar(254) not null, 
	"CREATE" 	number(19), 
	"LASTUPDATE" 	number(19), 
	"CREATOR" 	varchar(254), 
	"LASTUPDATOR" 	varchar(254), 
	"DOCUMENT" 	xmltype)
	xmltype column "DOCUMENT" store as binary xml;

ALTER TABLE GROUPUSAGELISTACLS 
	ADD CONSTRAINT PK_GRPUSAGEACL 
	PRIMARY KEY ("ID");

exit
ENDOFSQL

