import sys

#---------------------------------------------------------------------
#  def: print IBM Copyright
#---------------------------------------------------------------------
def printCopyright():
   print """
      ***************************************************************
      Licensed Materials - Property of IBM
      5724-O05
      (c) Copyright IBM Corp. 2006, 2008 All Rights Reserved.
      Trademark of International Business Machines
      ***************************************************************
   
   """
#endDef printCopyright

#-----------------------------
# usage output
#-----------------------------
def usage():
   print """
   
      Syntax: ./wsadmin -lang jython -f configureREP.py -rep <repName>
	  {-cluster <clusterName> | -node <node> -server <server>} 
	  -props <properties>
 
      rep - rep name
      node - node name
	  server - server name (must be accompanied by the node argument)
	  cluster - cluster name
	  props - comma deliniated list of attribute value pairs to configure
 
      Example:
         ./wsadmin.sh -lang jython -f configureREP.py -rep ibm-xdms
		 -cluster SharedListCluster 
		 -props xcapRoot=http://localhost:9080/services,superAdminUser=admin
		 
   """
   sys.exit(2)
   
#------------------------------------------------
# Helpers
#------------------------------------------------
def exception(excep, retCode):
   sys.stderr.write('An exception occurred: '+excep+'\n')
   if( retCode > 0 ):
      sys.exit(retCode)
#endDef exception

def saveAndSync():
   sys.stdout.write('Saving configuration changes.\n')
   AdminConfig.save()
   sys.stdout.write('Configuration was successfully saved.\n')
   #AdminConfig.sync()
   #sys.exit(0)
#endDef saveAndSync

# Takes in a list from a WSAdmin object and creates a Jython list out of it
def wsadminToList(inStr):
   outList=[]
   if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
      tmpList = inStr[1:-1].split(" ")
   else:
      tmpList = inStr.split("\n")  #splits for Windows or Linux
   for item in tmpList:
      item = item.rstrip();        #removes any Windows "\r"
      if (len(item)>0):
         outList.append(item)
   return outList
#endDef

#------------------------------------------------
# Functions
#------------------------------------------------
def buildContainmentPath(scopeId):
   outputStr = ""
   stIndex = scopeId.find("(") + 1
   endIndex = scopeId.find("|")
   scopeLst = scopeId[stIndex:endIndex].split("/")
   scopeListLen = len(scopeLst)
   for i in range(0, scopeListLen, 2):
      scopeType = scopeLst[i]
      scopeValue = scopeLst[i+1]
      if(scopeType == "cells"):
         outputStr = "/Cell:%s/" % scopeValue
      elif(scopeType == "clusters"):
         outputStr += "ServerCluster:%s/" % scopeValue
      elif(scopeType == "nodes"):
         outputStr += "Node:%s/" % scopeValue
      elif(scopeType == "servers"):
         outputStr += "Server:%s/" % scopeValue
   return outputStr
   
def getJ2EEProp(name, value):
   return [["name", name], ["value", value]]
   
def getPropSet(repId):
   propSet = AdminConfig.showAttribute(repId, 'propertySet') 
   if(propSet is None):
      propSet = AdminConfig.create('J2EEResourcePropertySet', repId, [])
      sys.stdout.write("A new Property Set was created.\n")
   return propSet
   
def setProperty(propSet, name, value):
   rps = AdminConfig.showAttribute(propSet, 'resourceProperties')
   propArray = rps[1:len(rps)-1].split(' ') 
   found = 0
   for prop in propArray:
      attr = AdminConfig.showAttribute(prop, 'name')
      if attr == name:
         sys.stdout.write("Entry '"+name+"' was found.\n")
         AdminConfig.modify(prop, [['name', name],['value', value]])
         sys.stdout.write("Entry '"+name+"' was successfully modified.\n")
	 found = 1
   if(not found):
      sys.stdout.write("Entry '"+name+"' was not found.\n")
      rpAttrs = getJ2EEProp(name, value)
      AdminConfig.create('J2EEResourceProperty', propSet, rpAttrs)
      sys.stdout.write("Entry '"+name+"' was successfully created.\n")

def setProps(props, propSet):
   if (props is not None and len(props)>0):
      try:
         avpList = props.split(",")
      except:
         avpList = [props]
      
      for item in avpList:
         avp = item.split("=")
         if (2==len(avp)):
            setProperty(propSet, avp[0], avp[1])
         else:
            sys.stdout.write("Discarding '"+item+"' as it's in an improper format")
#endDef
	
###############################################################################
# Main
###############################################################################

#*************************
# Global Constants
#*************************
linesep = java.lang.System.getProperty('line.separator')

#*************************
# Member Variables
#*************************
nodeName="" # if nodeName=="" then a cell is assumed
rep=None
props=None
nodeName=None
serverName=None
clusterName=None
scopeId=None
clusterInstall=0
retCode=0

#------------------------------------------------
# Gather arguments
#------------------------------------------------
count = 0
arglen = len(sys.argv)

if( arglen == 0 ):
   usage()
   

while (count < arglen):
   paramflag = sys.argv[count]
   count = count+1 
   
   if (cmp(paramflag, "-rep") == 0):
      param = sys.argv[count]
      rep = param
   elif (cmp(paramflag, "-node") == 0):
      param = sys.argv[count]
      nodeName = param
   elif (cmp(paramflag, "-server") == 0):
      param = sys.argv[count]
      serverName = param
   elif (cmp(paramflag, "-cluster") == 0):
      param = sys.argv[count]
      clusterName = param
      clusterInstall = 1
   elif (cmp(paramflag, "-props") == 0):
      param = sys.argv[count]
      props = param

   #endIf 
 
   count = count+1
#endWhile 

#------------------------------------------------
# Validate the variables
#------------------------------------------------
if(rep is None):
   exception("-rep is a required argument", 100)

#------------------------------------------------
# Get scope variable
#------------------------------------------------
if(clusterInstall):
   scopeId = AdminConfig.getid("/ServerCluster:"+clusterName+"/")
   if len(scopeId)== 0:
      exception("The cluster '"+clusterName+"' does not exist.\n")
else:
   if(nodeName is None or serverName is None):
      exception("You have not specified a valid target scope.  Include the -cluster or -server and -node arguments", 103)
   scopeId = AdminConfig.getid("/Node:"+nodeName+"/Server:"+serverName+"/")
   if len(scopeId) == 0:
      exception("The node '"+nodeName+"' or server '"+serverName+"' does not exist.\n")

#------------------------------------------------
# Get the REP entry
#------------------------------------------------
path =  buildContainmentPath(scopeId)+"ResourceEnvironmentProvider:"+rep+"/"
repId = AdminConfig.getid(path)
if(repId is None or "" == repId):
   exception("The rep '"+rep+"' does not exist", 105)
sys.stdout.write("The REP '"+rep+"' has been found.\n")

#------------------------------------------------
# Get the REP entry custom property
#------------------------------------------------
propSet = getPropSet(repId)
sys.stdout.write("The J2EEPropertySet for the REP has been retrieved.\n")

if(props is not None):
   setProps(props, propSet)
   saveAndSync()
else:
   sys.stdout.write("No properties were given with the -props argument\n")

sys.stdout.write('Configuration completed successfully\n')
sys.stdout.write('Done.\n')
sys.exit(retCode)
