import sys


#---------------------------------------------------------------------
#  def: print IBM Copyright
#---------------------------------------------------------------------
def printCopyright():
   print """
      ***************************************************************
      Licensed Materials - Property of IBM
      5724-O05
      (c) Copyright IBM Corp. 2006, 2008 All Rights Reserved.
      Trademark of International Business Machines
      ***************************************************************
   
   """
#endDef printCopyright

#-----------------------------
# usage output
#-----------------------------
def usage():
   print """
   
      Syntax: ./wsadmin -lang jython -f configureTAI.py -className <className>
	  -props <property_name>~<value>~<optional description>#,#<property_name>
	  ~<value>~<optional description> -forceWrite 
 
      className - class name
      props - "#,#" deliniated list of attribute value pairs to configure
      forceWrite - flag to overwrite the properties of an existing TAI
      
      Example:
         ./wsadmin.sh -lang jython -f configureTAI.py -className 
            com.ibm.imsconnector.tai.SipInterceptor -props 
            assertedIdentityHeaderType~P-Asserted-Identity~Comma-delineated list...#,#
            enableDefaultRoleMapping~false~Enables default role mapping
            -forceWrite
		 
   """
   sys.exit(2)
   
#------------------------------------------------
# Helpers
#------------------------------------------------
def exception(excep, retCode):
   sys.stderr.write('An exception occurred: '+excep+'\n')
   if( retCode > 0 ):
      sys.exit(retCode)
#endDef exception

def saveAndSync():
   sys.stdout.write('Saving configuration changes.\n')
   AdminConfig.save()
   sys.stdout.write('Configuration was successfully saved.\n')
#endDef saveAndSync

# Takes in a list from a WSAdmin object and creates a Jython list out of it
def wsadminToList(inStr):
   outList=[]
   if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
      tmpList = inStr[1:-1].split(" ")
   else:
      tmpList = inStr.split("\n")  #splits for Windows or Linux
   for item in tmpList:
      item = item.rstrip();        #removes any Windows "\r"
      if (len(item)>0):
         outList.append(item)
   return outList
#endDef

#------------------------------------------------
# Functions
#------------------------------------------------
def getJ2EEProp(name, value, desc):
   return [["name", name], ["value", value], ["description", desc]]

def createTAI(props):
   pr = []
   if (props is not None and len(props)>0):
      try:
         avpList = props.split("#,#")
      except:
         avpList = [props]
         
      for item in avpList:
         avp = item.split("~")
         if (3==len(avp)):
	    if avp[0].startswith("Ldap") and wasVersion.startswith("7"):
		sys.stdout.write("Ldap related custom properties being skipped for WAS version 7 or higher \n")
	    else:
	        prTemp= getJ2EEProp(avp[0], avp[1], avp[2])
                sys.stdout.write("Property '"+ avp[0]+"' with value '"+ avp[1]+ "' written.\n")
                sys.stdout.write("Description = " + avp[2] + "\n")
                pr.append(prTemp)
         elif (2==len(avp)):
	    if avp[0].startswith("Ldap") and wasVersion.startswith("7"):
		sys.stdout.write("Ldap related custom properties being skipped for WAS version 7 or higher \n")
	    else:
                prTemp= getJ2EEProp(avp[0], avp[1], [])
                sys.stdout.write("Property '"+ avp[0]+"' with value '"+ avp[1]+ "' written.\n")
                sys.stdout.write("Description = NONE. \n")
                pr.append(prTemp)
         else:
            sys.stdout.write("Discarding '"+item+"' as it's in an improper format")       
   trustProps = ["trustProperties", pr]
   interceptorClassName = ["interceptorClassName", className]
   attrs = [interceptorClassName, trustProps]
   AdminConfig.create("TAInterceptor", trustAssociation, attrs)                    
#endDef 
	
###############################################################################
# Main
###############################################################################

#*************************
# Global Constants
#*************************
linesep = java.lang.System.getProperty('line.separator')

#*************************
# Member Variables
#*************************
className=None
props=None
retCode=0
overwrite=0
existingTAI=0
wasVersion = None
#------------------------------------------------
# Gather arguments
#------------------------------------------------
count = 1
arglen = len(sys.argv)

if( arglen == 0 ):
   usage()
   
while (count < arglen):
   wasVersion = sys.argv[0]
   paramflag = sys.argv[count]
   count = count+1 
   
   if (cmp(paramflag, "-className") == 0):
      param = sys.argv[count]
      className = param
   elif (cmp(paramflag, "-props") == 0):
      param = sys.argv[count]
      props = param
      count = count+1
      while (count < arglen):
      	 if (cmp(sys.argv[count], "-forceWrite")== 0):
      	    count = count-1
            break
         if (cmp(sys.argv[count], "-className")== 0):
            count = count-1
            break
         param = sys.argv[count]
         props = props + " " + param
         count = count+1
   elif (cmp(paramflag, "-forceWrite") == 0):
      overwrite = 1
      count = count-1
   #endIf 
   count = count+1
#endWhile 

#------------------------------------------------
# Validate the variables
#------------------------------------------------
if(className is None):
   exception("-className is a required argument", 100)

#------------------------------------------------
# Enable Trust Association & Define Interceptors
#------------------------------------------------
cell = AdminControl.getCell()
WASsec = AdminConfig.getid("/Cell:" + cell + "/Security:/")
print('Configuring TAInterceptor on the WebSphere Cell: ' + cell + '\n')
authMechanismsAttr = AdminConfig.showAttribute(WASsec, "authMechanisms")
WASauthMechanisms = wsadminToList(authMechanismsAttr)

#For LTPA auth mechanism, enable trust association, then define IMS SIP and http interceptors
for authMech in WASauthMechanisms:
   authMechName =  AdminConfig.showAttribute(authMech, "simpleAuthConfig")
   if (authMechName == "system.LTPA"):
      trustAssociation  =  AdminConfig.showAttribute(authMech, "trustAssociation")
      AdminConfig.modify(trustAssociation, [["enabled", "true"]])

      taiList = wsadminToList(AdminConfig.list("TAInterceptor"))
      for installedTAI in taiList:
         # Check for existing className         
         taiClassName= AdminConfig.showAttribute(installedTAI, "interceptorClassName")
         if(taiClassName == className): # TAI exists
            sys.stdout.write('TAI interceptor ' + str(taiClassName) + ' exists.\n')
            existingTAI = 1
            if (overwrite):
               AdminConfig.remove(installedTAI)
               sys.stdout.write('TAI '+className+' has been removed.\n')
               sys.stdout.write('Installing ' + className + '...\n')
               createTAI(props)
               sys.stdout.write('TAI configuration completed successfully\n')
            else:
               sys.stdout.write("No changes were made.\n")
               sys.stdout.write("Use '-forceWrite' to change properties.\n")
               sys.stdout.write('Done.\n')
               sys.exit(retCode)
      if (existingTAI == 0):  # TAI does not currently exist
         sys.stdout.write('Installing ' + className + '...\n')
         createTAI(props)
            
      #end for
   #end if
#end for
saveAndSync()
sys.stdout.write('Done.\n')
sys.exit(retCode)
