import sys

#---------------------------------------------------------------------
#  def: print IBM Copyright
#---------------------------------------------------------------------
def printCopyright():
   print """
      ***************************************************************
      Licensed Materials - Property of IBM
      5724-O05
      (c) Copyright IBM Corp. 2006, 2008 All Rights Reserved.
      Trademark of International Business Machines
      ***************************************************************
   
   """
#endDef printCopyright

#-----------------------------
# usage output
#-----------------------------
def usage():
   print """
   
      Syntax: ./wsadmin -lang jython -f createDatasource.py -dbType <db2|oracle> 
	  -dbHost <hostname> -dbPort <port> -dbName <name> 
	  -dbUser <user> -dbPass <pass> -jndiName <jndiName> 
	  -dbDriverPath <pathToJars> [-node <nodeName>] [-nonxa]
 
      dbType - either "db2" or "oracle" database
	  dbHost - hostname of the database server
	  dbPort - listening port of the database server
	  dbName - database name (db2) or oracle SID (oracle)
      dbUser - user ID for database
      dbPass - password of database user
      dbDriverPath - class path to database JDBC Driver jars
	  jndiName - JNDI name for the resource
	  node - specify a node rather than the default scope of Cell (Optional as cell is assumed)
	  nonxa - flag to indicate creation of a non-xa datasource (XA is default)
 
      Example:
         ./wsadmin.sh -lang jython -f createDatasource.py -dbType db2 
		 -dbHost localhost -dbPort 50000 -dbName XDMS -jndiName jdbc/xdms
		 -dbUser db2inst1 -dbPass db2admin -dbDriverPath /opt/ibm/db2/V9.5/java
		 
   """
   sys.exit(2)
     
#------------------------------------------------
# Helpers
#------------------------------------------------
def exception(excep, retCode):
   sys.stderr.write('An exception occurred: '+excep+'\n')
   if( retCode > 0 ):
      sys.exit(retCode)
#endDef exception

def saveAndSync():
   sys.stdout.write('Saving configuration changes.\n')
   AdminConfig.save()
   sys.stdout.write('Configuration was successfully saved.\n')
   #AdminConfig.sync()
   #sys.exit(0)
#endDef saveAndSync

# Takes in a list from a WSAdmin object and creates a Jython list out of it
def wsadminToList(inStr):
   outList=[]
   if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
      tmpList = inStr[1:-1].split(" ")
   else:
      tmpList = inStr.split("\n")  #splits for Windows or Linux
   for item in tmpList:
      item = item.rstrip();        #removes any Windows "\r"
      if (len(item)>0):
         outList.append(item)
   return outList
#endDef

#------------------------------------------------
# Functions
#------------------------------------------------
def getDatasourceName(dbType, jndiName):
   return 'XDMS_' + dbType.upper() + '_' + jndiName.replace('/','-').upper() + '_DataSource'
#endDef

def getAuthAliasName(dbType, dbUser):
   return 'xdms_' + dbType + '_' + dbUser
#endDef
 
###############################################################################
# Main
###############################################################################

#*************************
# Global Constants
#*************************
linesep = java.lang.System.getProperty('line.separator')

#*************************
# Member Variables
#*************************
nodeName="" # if nodeName=="" then a cell is assumed
dbType=""
dbName=""
dbHost=""
dbPort=""
dbUser=""
dbPass=""
dbDriverPath=""
dsJNDIName=""
nonxa=0
skip=""
retCode=0

#------------------------------------------------
# Gather arguments
#------------------------------------------------
count = 0
arglen = len(sys.argv)

if( arglen == 0 ):
   usage()
   

while (count < arglen):
   paramflag = sys.argv[count]
   count = count+1 
   
   if (cmp(paramflag, "-dbType") == 0):
      param = sys.argv[count]
      dbType = param.lower()
   elif (cmp(paramflag, "-node") == 0):
      param = sys.argv[count]
      nodeName = param
   elif (cmp(paramflag, "-dbDriverPath") == 0):
      param = sys.argv[count]
      dbDriverPath = param
   elif (cmp(paramflag, "-dbHost") == 0):
      param = sys.argv[count]
      dbHost = param.lower()
   elif (cmp(paramflag, "-dbPort") == 0):
      param = sys.argv[count]
      dbPort = param
   elif (cmp(paramflag, "-dbUser") == 0):
      param = sys.argv[count]
      dbUser = param
   elif (cmp(paramflag, "-dbPass") == 0):
      param = sys.argv[count]
      dbPass = param
   elif (cmp(paramflag, "-jndiName") == 0):
      param = sys.argv[count]
      dsJNDIName = param
   elif (cmp(paramflag, "-dbName") == 0):
      param = sys.argv[count]
      dbName = param
   elif (cmp(paramflag, "-skip") == 0):
      param = sys.argv[count]
      skip = param
   elif (cmp(paramflag, "-nonxa") == 0):
      nonxa = 1
   #endIf 
 
   count = count+1
#endWhile 

if (skip == "true" ):
   sys.exit(retCode)

#------------------------------------------------
# Validate the variables
#------------------------------------------------


#------------------------------------------------
# Setup database properties by type
#------------------------------------------------
if (dbType == "db2"):
   dsDescription="XDMS DB2 JDBC Datasource"
   providerDescription="DB2 JDBC Provider for XDMS"
   datasourceHelperClassname="com.ibm.websphere.rsadapter.DB2UniversalDataStoreHelper"
   if (nonxa == 1):
      providerName="XDMS DB2 JDBC Provider (non-XA)"
      implementationClassName="com.ibm.db2.jcc.DB2ConnectionPoolDataSource"
   else:
      providerName="XDMS DB2 JDBC Provider (XA)"
      implementationClassName="com.ibm.db2.jcc.DB2XADataSource"
elif (dbType == "oracle"):
   dsDescription="XDMS Oracle JDBC DataSource"
   providerDescription="Oracle JDBC Provider for XDMS"
   datasourceHelperClassname="com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper"
   if (nonxa == 1):
      providerName="XDMS Oracle JDBC Provider (non-XA)"
      implementationClassName="oracle.jdbc.pool.OracleConnectionPoolDataSource"
   else:
      providerName="XDMS Oracle JDBC Provider (XA)"
      implementationClassName="oracle.jdbc.xa.client.OracleXADataSource"
else:
   sys.stderr.write('The database type argument value "' + dbType +'" is invalid\n')
   usage()

#------------------------------------------------
# Get the Cell name for use in resource creation
#------------------------------------------------
print "Determining WebSphere configuration data..."

cell=AdminConfig.list("Cell")
if (cell == ""):
   sys.stderr.write('A valid Cell is not available.\n')
   exception('A Cell must be configured in the environment.', 101)
else:
   cellName=AdminControl.getCell()
   sys.stdout.write('Configuring JDBC Provider on the WebSphere Cell: ' + cell + '\n')

#------------------------------------------------
# If using a node, check to see that it exists
#------------------------------------------------
if (nodeName != ""):
   sys.stdout.write('Checking if the target node ' + nodeName + ' exists...\n')
   node = None
   nodesString = AdminConfig.list('Node')
   nodes = wsadminToList(nodesString)
   for n in nodes:
      nodeNameAttr = AdminConfig.showAttribute(n, 'name')
      if (( nodeNameAttr == nodeName ) ):
         sys.stdout.write('The Node ' + n + ' exists\n')
         node = n
         break

   if (node is None):
      sys.stderr.write('The Node ' + nodeName + ' does not exist.\n')
      exception('Ensure that the value for the node argument is correct.', 100)

#------------------------------------------------
# Determine the scope, Node or Cell
#------------------------------------------------
if (nodeName != ""):
   scope=node
else:
   scope=cell

#------------------------------------------------
# JAAS Authentication Alias Creation
#------------------------------------------------
authAliasName=getAuthAliasName(dbType, dbUser)
sys.stdout.write('Configuring the JAAS Authenticaton Alias...\n')

if(dsJNDIName == ""):
   sys.stderr.write('The jndiName argument is required.\n')
   usage()
if(dbUser == ""):
   sys.stderr.write('The dbUser argument is required.\n')
   usage()
if(dbPass == ""):
   sys.stderr.write('The dbPass argument is required.\n')
   usage()

# Create at the cell level
security = AdminConfig.getid('/Cell:' + cellName + '/Security:/')
sys.stdout.write("security is: " +str(security)+"\n")
jaasAttrs=[["alias", authAliasName], ["userId", dbUser], ["password", dbPass]]
sys.stdout.write("jaasAttrsis: " +str([["alias", authAliasName], ["userId", dbUser], ["password", "****"]])+"\n")
AuthAliasList=AdminConfig.list("JAASAuthData")
entries = wsadminToList(AuthAliasList)
aliasEntry = ''
aliasExists = 0
for entry in entries:
	aliasEntry = AdminConfig.showAttribute(entry, 'alias')
	sys.stdout.write("aliasName is " + aliasEntry + " and searching for " + authAliasName+"\n") 
	if (aliasEntry == authAliasName):
		aliasExists = 1
   		sys.stdout.write('The JAAS Authentication Alias ' + authAliasName + ' already exists.\n')
#end for

if (aliasExists == 0):
	try:
		sys.stdout.write("Security is: " + security+"\n");
		authDataAlias=AdminConfig.create("JAASAuthData", security, jaasAttrs)
 	except:
   		#print "some error occurred..."
		temp = str(sys.exc_value)
	   	index = temp.find('existing JAASAuthData')
		if ( index < 0 ):
      			exception( str(sys.exc_value), 103 )
   		else:
      			sys.stdout.write('The JAAS Authentication Alias ' + authAliasName + ' already exists.\n')
      			retCode=1
   		#endIf
#end if

   			
   
#------------------------------------------------
# JDBC Provider Creation
#------------------------------------------------
sys.stdout.write('Configuring the JDBC Provider...\n')

if(dbDriverPath == ""):
   sys.stderr.write('The dbDriverPath argument is required.\n')
   usage()
   
count = 0
provider = None
providers=AdminConfig.list('JDBCProvider')
#providersList=wsadminToList(providers)
# iterate through providers list to see if providerName already exists
for i in providers:
   #if (cmp(providerName, i) == 0):   
   if i == providerName[count]:
      count=count+1
   else:
      count= 0
   if (count == len(providerName)):
      sys.stdout.write('The JDBC Provider "' + providerName + '" already exists.\n')
      # grab the ID for this provider and store it into var provider
      provider=AdminConfig.getid("/JDBCProvider:" + providerName + "/")
      retCode=1
      break

# Create the JDBC Provider if it does not exist
if (provider == None):
   providerAttrs=[]
   providerAttrs.append(["classpath", dbDriverPath])
   providerAttrs.append(["implementationClassName", implementationClassName])
   providerAttrs.append(["name", providerName])
   providerAttrs.append(["description", providerDescription])
   if (dbType == "oracle"):
      providerAttrs.append(["nativepath", dbDriverPath])
   #endIf
   
   try:
      provider=AdminConfig.create("JDBCProvider", scope, providerAttrs)
      sys.stdout.write('The JDBC Provider "' + providerName + '" has been created.\n')
   except:
      exception( str(sys.exc_value), 104 )
#endIf

#------------------------------------------------
# DataSource creation
#------------------------------------------------
dsName = getDatasourceName(dbType, dsJNDIName)
sys.stdout.write('Configuring the DataSource: '+dsName +'...\n')

if (dbType == "db2"):
   if(dbHost == ""):
      sys.stderr.write('The dbHost argument is required when creating a DataSource.\n')
      usage()      
   if(dbPort == ""):
      sys.stderr.write('The dbPort argument is required when creating a DataSource.\n')
      usage()
      
# Create a new datasource if it does not exists

#=================
dsexists=0
for item in wsadminToList(AdminConfig.list("DataSource")):
	itemDSName = item[0:item.find("(")]
	sys.stdout.write('Existing DataSource name:' + itemDSName + '.\n')
        if (itemDSName == dsName):
        	sys.stdout.write('The DataSource ' + dsName + ' already exists.\n')
        	dsexists=1
      		retCode=1
		break 
	#endif
#end for
if(not dsexists):
	sys.stdout.write('DataSource '+dsName+ ' does not exists. Will configure a new one.\n')
	try:
	   dsAttrs=[["name", dsName], ["description", dsDescription]]
	   datasource=AdminConfig.create("DataSource", provider, dsAttrs)
	   dsAttrs=[]
	   dsAttrs.append(["jndiName", dsJNDIName])
	   dsAttrs.append(["datasourceHelperClassname", datasourceHelperClassname])
	   dsAttrs.append(["authDataAlias", authAliasName])
	   dsAttrs.append(["xaRecoveryAuthAlias", authAliasName])
	   AdminConfig.modify(datasource, dsAttrs)
	 
	   # Set the datasource properties
	   propSet1 = AdminConfig.create("J2EEResourcePropertySet", datasource, [])
	   if (dbType == "db2"):
	      if(dbName == ""):
	         sys.stderr.write('The dbName argument is required when creating a DB2 DataSource.\n')
	   	 usage()
	      
	      attrs1 = [["name", "databaseName"], ["type", "java.lang.String"], ["value", dbName]]
	      attrs2 = [["name", "driverType"], ["type", "java.lang.Integer"], ["value", "4"]]
	      attrs3 = [["name", "serverName"], ["type", "java.lang.String"], ["value", dbHost]]
	      attrs4 = [["name", "portNumber"], ["type", "java.lang.Integer"], ["value", dbPort]]
	      AdminConfig.create("J2EEResourceProperty", propSet1, attrs1)
	      AdminConfig.create("J2EEResourceProperty", propSet1, attrs2)
	      AdminConfig.create("J2EEResourceProperty", propSet1, attrs3)
	      AdminConfig.create("J2EEResourceProperty", propSet1, attrs4)
	      retCode=0
	      sys.stdout.write('The DataSource ' + dsName + ' is being configured.\n')
	   elif (dbType == "oracle"):
	      if(dbName == ""):
	         sys.stderr.write('The dbName argument is required when creating an Oracle DataSource.\n')
	   	 usage()
	      tns = "jdbc:oracle:thin:@" + dbHost + ":" + dbPort + ":" + dbName
	      attrs1 = [["name", "URL"], ["type", "java.lang.String"], ["value", tns]]
	      AdminConfig.create("J2EEResourceProperty", propSet1, attrs1)
	      retCode=0
	      sys.stdout.write('The DataSource ' + dsName + ' has been created.\n')
	except:
	   temp = str(sys.exc_value)
	   index = temp.find('existing DataSource')
	   if ( index < 0 ):
	      exception( str(sys.exc_value), 105 )
	   else:
	      sys.stdout.write('The DataSource ' + dsName + ' already exists.\n')
	      retCode=1
	   #endIf


saveAndSync()
sys.stdout.write('Configuration completed successfully\n')
sys.stdout.write('Done.\n')
sys.exit(retCode)
