import sys
import string
import os.path

#---------------------------------------------------------------------
#  def: print IBM Copyright
#---------------------------------------------------------------------
def printCopyright():
   print """
      ***************************************************************
      Licensed Materials - Property of IBM
      5724-O05
      (c) Copyright IBM Corp. 2006, 2008 All Rights Reserved.
      Trademark of International Business Machines
      ***************************************************************
   
   """
#endDef printCopyright

#-----------------------------
# usage output
#-----------------------------
def printUsage():
   print """
   
      Syntax: ./wsadmin -lang jython -f deployEar.py 
	  -state <INSTALL|UNINSTALL|UPGRADE> -ear <pathToEar> -app <appName> 
	  {-cluster <clusterName> | -node <node> -server <server>} 
	  -wasHome <wasHome>
 
	  state - maintenance to perform on the application (INSTALL, UNINSTALL, or UPGRADE)
      node - node name
	  server - server name (must be accompanied by the node argument)
	  cluster - cluster name
	  ear - the path to the ear file
	  app - display name for the application
	  wasHome - path to the root directory of the WebSphere installation
      
      Example:
         ./wsadmin.sh -lang jython -f deployEar.py -state INSTALL
		 -ear /opt/IBM/WebSphere/AppServer/installableApps/xdms/IBMSharedListXdms.ear
		 -app "Shared List XDMS" -cluster SharedListCluster 
		 -wasHome /opt/IBM/WebSphere/AppServer/
		 
   """   
   	
   
   	
#-----------------------------------------------------------------
# Functions
#-----------------------------------------------------------------
def cleanStr( string ):
   retVal = string.replace(' ', '_')
   retVal = retVal.strip()
   return retVal
#endDef cleanStr

def cleanApp( string ):
   retVal = string.replace('\'', '')
   retVal = string.replace('\"', '')
   retVal = retVal.strip()
   return retVal
#endDef cleanApp

# Takes in a list from a WSAdmin object and creates a Jython list out of it
def wsadminToList(inStr):
   outList=[]
   if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
      tmpList = inStr[1:-1].split(" ")
   else:
      tmpList = inStr.split("\n")  #splits for Windows or Linux
   for item in tmpList:
      item = item.rstrip();        #removes any Windows "\r"
      if (len(item)>0):
         outList.append(item)
   return outList
#endDef

#-----------------------------------------------------------------
# Validation Functions
#-----------------------------------------------------------------
def validate():
   if ( wasHome == "" ):
      printUsage()
      exception('You must specify a WAS_HOME directory with the -wasHome argument\n', 2)
   #endIf 
#endDef validate

def validateEar():
   if ( ear == "" ):
      exception('No EAR was specified for configuration.\n', 3)
   if ( not (os.path.isfile(ear)) ):
      exception('The EAR ' + ear + ' was not found.\n', 4)
   sys.stdout.write('Ear file location: '+ear+'\n')
#endDef validateEar

def validateTarget():
   if ( clustered ):
      if ( not ( isValidCluster(clusterName))):
         exception('Cluster "' + clusterName + '" specified was not found on this cell ', 11 )
   else:
      if ( (nodeName == "") or (serverName == "") ):
         printUsage()
         exception('-node and -server are required arguments\n', 14)
      #endIf
      
      if ( not ( isValidNode(nodeName))):
      	 printUsage()
         exception('The specified Node "' + nodeName + '" was not found on this cell', 12 )
      #endIf
      
      if ( not (isValidServer( serverName ))):
      	 printUsage()
         exception('The specified Server "' + serverName + '" was not found on this node', 13 )
      #endIf
   #endIf
   
#endDef validate#endDef validateTarget

def validateApp():
   if( app == "Unknown XDMS Application" ):
      exception('Must include -app flag\n', 6)
#endDef validateApp

def validateOptions():
   if( options == "" ):
      exception('Must include -options flag when upgrading\n', 7)
   sys.stdout.write('Options are valid: '+options+'\n')
#endDef validateOptions

#-----------------------------------------------------------------
# Helpers
#-----------------------------------------------------------------
def exception(excep, retCode):
   sys.stderr.write('An exception occurred: '+excep+'\n')
   sys.exit(retCode)
#endDef exception

def saveAndSync():
   sys.stdout.write('Saving configuration changes.\n')
   AdminConfig.save()
   sys.stdout.write('Configuration was successfully saved.\n')
   #AdminConfig.sync()
   #sys.exit(0)
#endDef saveAndSync

# Returns true (1) if the given cluster name is located
def isValidCluster( clusterParm ):
   global scope
   scope = AdminConfig.getid("/ServerCluster:"+clusterName+"/")
   if len(scope) != 0:
      return 1
   else:
      return 0     
#endDef

# Returns true (1) if the given node name is located
def isValidNode( nodeParm ):
   global scope
   valid = 0
   elementsString = AdminConfig.list('Cell')
    
   if debug:
      sys.stdout.write('elementsString= ' + elementsString + '\n')
   #endIf
        
   elements = wsadminToList(elementsString)
   for element in elements:  

      if debug:
         sys.stdout.write('element= ' + element + '\n')
      #endIf
        
      nodesString = AdminConfig.list('Node')
        
      if debug:
         sys.stdout.write('nodesString= ' + nodesString + '\n')
      #endIf
        
      nodes = wsadminToList(nodesString)
     
      for node in nodes:  
         nodeName = AdminConfig.showAttribute(node, 'name')
            
         if debug:
            sys.stdout.write('node ' + node + ' has name attribute = ' + nodeName + '\n')
         #endIf
             
         if (( nodeName == nodeParm ) ):
            valid = 1
            scope = node
            break 
         #endIf 
      #endFor 
   #endFor
   return valid
 #endDef 

# Returns true (1) if the given server name is located
def isValidServer( serverName ):
   # global debug
   valid = 0
   elementsString = AdminConfig.list('Cell')

   if debug:
      sys.stdout.write('elementsString= ' + elementsString + '\n')
   #endIf
        
   elements = wsadminToList(elementsString)
   for element in elements:  
      if debug:
         sys.stdout.write('element= ' + element + '\n')
      #endIf
        
      serversString = AdminConfig.list('Server')
        
      if debug:
         sys.stdout.write('serversString= ' + serversString + '\n')
      #endIf
        
      servers = wsadminToList(serversString)
     
      for server in servers:  
         srvName = AdminConfig.showAttribute(server, 'name')
          
         if debug:
            sys.stdout.write('server ' + server + ' has name attribute = ' + srvName + '\n')
         #endIf
            
         if (( srvName == serverName) ):
            valid = 1
            break 
         #endIf 
      #endFor 
   #endFor
   return valid
#endDef 


#-----------------------------------------------------------------
# Actions
#-----------------------------------------------------------------
def install():
   validateEar()
   validateTarget()   
   sys.stdout.write('Performing installation ...\n')
   try:
      if ( clustered ):
         sys.stdout.write('Installing application on cluster ' + clusterName+'\n')
         AdminApp.install(ear, ['-cluster', clusterName])
         saveAndSync()
      else:
         sys.stdout.write('Installing application on server ' + serverName+'\n')
         AdminApp.install(ear, ['-node', nodeName, '-server', serverName])
         saveAndSync()
      sys.stdout.write('Installation was successful\n')
   except:
      exception( str(sys.exc_value), 4 )
#endDef install	
		
def upgrade():
   validateApp()
   validateEar()
   sys.stdout.write('Performing upgrade ...\n')
   options = "[-operation update -contents "+ear+" -nopreCompileJSPs -distributeApp -nouseMetaDataFromBinary -deployejb -createMBeansForResources -nodeployws -validateinstall warn -noprocessEmbeddedConfig -noallowDispatchRemoteInclude -noallowServiceRemoteInclude -update.ignore.new]"
   try:
      sys.stdout.write('Updating appliation.\n')
      sys.stdout.write( "Running command: AdminApp.update("+app+", 'app'," +options+")\n" );
      AdminApp.update(app, 'app', options)
      saveAndSync()
      sys.stdout.write('Update was successful\n')
   except:
      exception( str(sys.exc_value), 3 )
#endDef upgrade
      
def uninstall():
   validateApp()
   sys.stdout.write('Performing uninstallation...\n')
   try:
      sys.stdout.write('Uninstalling application\n')
      AdminApp.uninstall(app)
      saveAndSync()
      sys.stdout.write('Installation was successful\n')
   except:
      exception( str(sys.exc_value), 2 )
#endDef uninstall

#-----------------------------------------------------------------
# Main
#-----------------------------------------------------------------

# Member fields
nodeName = ""
scope = ""
scopeName = ""
serverName = ""
clusterName = ""
options = ""
ear = ""
app = "Unknown XDMS Application"
wasHome = ""
debug = 0
clustered = 0
state = 'NOACTION'
	# View MaintenanceState emum for more information
	# state NONE/NOACTION == noaction
	# state INSTALL == install
	# state UPDATE == update
	# state UNINSTALL == uninstall

# IBM Legal Statement
printCopyright()

# Init loop params
count = 0
arglen = len(sys.argv)
while (count < arglen):
   paramflag = sys.argv[count]
   count = count+1 
   if (cmp(paramflag, "-ear") == 0):
      param = sys.argv[count]
      ear = param
   elif (cmp(paramflag, "-app") == 0):
      param = sys.argv[count]
      app = param
   elif (cmp(paramflag, "-node") == 0):
      param = sys.argv[count]
      nodeName = param
   elif (cmp(paramflag, "-server") == 0):
      param = sys.argv[count]
      serverName = param
   elif (cmp(paramflag, "-cluster") == 0):
      param = sys.argv[count]
      clusterName = param
      clustered = 1
   elif (cmp(paramflag, "-state") == 0):
      param = sys.argv[count]
      state = param
   elif (cmp(paramflag, "-wasHome") == 0):
      param = sys.argv[count]
      wasHome = param
   #endIf 
   count = count+1
#endWhile 

# Validate scripting environment
validate()

# Do any variable cleanup
app = cleanApp( app )

# Perform action
if ( state == 'INSTALL' ):
   install()
   
elif ( state == 'UPGRADE' ): 
   upgrade()
   
elif ( state == 'UNINSTALL' ):
   uninstall()

else:
   exception('No state defined.  Must use the -state flag.\n', 1);

sys.stdout.write('Done.\n')
sys.exit(0)
