import sys

#---------------------------------------------------------------------
#  def: print IBM Copyright
#---------------------------------------------------------------------
def printCopyright():
   sys.stdout.write( '***************************************************************\n\n\
   Licensed Materials - Property of IBM\n\
   5724-O05\n\
   (c) Copyright IBM Corp. 2006, 2008 All Rights Reserved.\n\
   * Trademark of International Business Machines\n')
   sys.stdout.write('***************************************************************\n\n')
#endDef printCopyright

#-----------------------------
# usage output
#-----------------------------
def usage():
   print """
      Syntax: wsadmin -f CreateJDBCResources.py dbType <-cell | nodeName>
      dbDriverPath dbUserName dbPassword [oracledbhost] [oraclesid]
 
      dbType      - either "db2" or "oracle" database
      nodeName    - configure resources at cell level or on specified node.
      dbDriverPath - class path to database JDBC Driver
      dbUserName  - user ID for database
      dbPassword  - password of database user ID
 
      Example:
         wsadmin -lang jython -f CreateJDBCResources.py db2 mybasehost
         /home/db2inst1/sqllib/java/db2java.zip db2user1 db2user1
   """
   sys.exit(2)
   
#------------------------------------------------
# Helpers
#------------------------------------------------
def exception(excep, retCode):
   sys.stderr.write('An exception occurred: '+excep+'\n')
   if( retCode > 0 ):
      sys.exit(retCode)
#endDef exception

###############################################################################
# Main
###############################################################################

#*************************
# Global Constants
#*************************
linesep = java.lang.System.getProperty('line.separator')

#*************************
# Member Variables
#*************************
nodeName="" # if nodeName=="" then a cell is assumed
dsJNDIName=""
retCode=0

#------------------------------------------------
# Gather arguments
#------------------------------------------------
count = 0
arglen = len(sys.argv)

if( arglen == 0 ):
   usage()
   
while (count < arglen):
   paramflag = sys.argv[count]
   count = count+1 
   
   if (cmp(paramflag, "-node") == 0):
      param = sys.argv[count]
      nodeName = param
   elif (cmp(paramflag, "-jndiName") == 0):
      param = sys.argv[count]
      dsJNDIName = param
   #endIf 
 
   count = count+1
#endWhile 

#------------------------------------------------
# Validate the variables
#------------------------------------------------

#------------------------------------------------
# Get the Cell name for use in resource creation
#------------------------------------------------
cell=AdminConfig.list("Cell")
if (cell == ""):
   sys.stderr.write('A valid Cell is not available.\n')
   exception('A Cell must be configured in the environment.', 101)
else:
   cellName=AdminControl.getCell()
   
#------------------------------------------------
# Find the node we want to add to the cluster
# Contingent on using a node (opposed to a Cell)
#------------------------------------------------
if (nodeName != ""):
   sys.stdout.write('Checking if the target node ' + nodeName + ' exists...\n')
   nodes=AdminConfig.list("Node")
   node=""
   if (nodes != ""):
      nodeList = nodes.split(linesep)
      i=0
      for n in nodeList:
         if (n.find(nodeName)):
            node=nodeList[i]
            sys.stdout.write('The Node ' + node + ' exists\n')
            break
         i+=1

   if (node == ""):
      sys.stderr.write('The Node ' + node + ' does not exist.\n')
      exception('Ensure that the value for the node argument is correct.', 100)

#------------------------------------------------
# Determine the scope, Node or Cell
#------------------------------------------------
if (nodeName != ""):
   scope=node
else:
   scope=cell

#------------------------------------------------
# Determine if DS with JNDI dsJNDIname exists
#------------------------------------------------
dataSourceEntries=AdminConfig.list("DataSource", scope)
if (dataSourceEntries != ""):
   dataSourceEntryList=dataSourceEntries.split(lineSeparator)

   for dataSourceEntry in dataSourceEntryList:
      #ds=AdminConfig.getid('/DataSource:'+dataSourceEntry+'/')
      jndi=AdminConfig.showAttribute(dataSourceEntry, 'jndiName')
      if(jndi == dsJNDIName):
      	retCode = 1;
      	break
      	
if(retCode == 0):
   sys.stdout.write('A DataSource with JNDI Name of ' + dsJNDIName + ' was not found.\n');	
else:
   sys.stdout.write('A DataSource with JNDI Name of ' + dsJNDIName + ' was found.\n');
      
sys.stdout.write('Done.\n')
sys.exit(retCode)
