#!/bin/bash
#
# Usage: restartServer.sh <profileHome> [server] [user] [password]
# Example:
# Deployment Manager:
#	./restartServer.sh /was/profiles/Dmgr01 dmgr wasadmin password
# Server:
#	./restartServer.sh /was/profiles/AppSrv01 server1 wasadmin password
#
# Arguments
#1 = profile directory (required)
#2 = server name (optional only for DMGR with no security)
#3 = was admin user (optional)
#4 = was admin password (optional)
##################################################

profileHome=$1
server=$2
user=$3
pass=$4

# Stopping servers when security is enabled will
# prompt the user interactively for password
# information, this hack gets around that
# and will warn the user of incorrect credentials
if [ -z "$user" ];
then
  user="_"
fi
if [ -z "$pass" ];
then
  pass="_"
fi

echo "1: $server  2: $pass 3: $user 4: $profileHome"

# Error checking
if [ ! -d $profileHome ];
then
  echo "$profileHome is not a valid profile directory"
  exit 1
fi

cd $profileHome/bin
echo "Changed to dir: $PWD"

# Is this is a deployment manager directory?
if [ -f startManager.sh ] && [ -f stopManager.sh ];
then
  echo "Restarting Deployment Manager"
  sh stopManager.sh -user $user -password $pass
  if [ $? != 0 ];
  then
    echo "Stopping the Deployment Manager was unsuccessful."
    exit 2
  fi
  sh startManager.sh
  if [ $? != 0 ];
  then
    echo "Starting the Deployment Manager was unsuccessful."
    exit 3
  fi
  echo "Servers successfully"
  
# Is it a server directory?
elif [ -f startServer.sh ] && [ -f stopServer.sh ];
then
  echo "Restarting application server"
  sh stopServer.sh $server -user $user -password $pass
  if [ $? != 0 ];
  then
    echo "Stopping the application server '$server' was unsuccessful."
    exit 4
  fi
  sh startServer.sh $server
  if [ $? != 0 ];
  then
    echo "Starting the application server '$server' was unsuccessful."
    exit 5
  fi
  echo "Server restarted successfully"
else
  echo "Invalid profile directory, no server management scripts found!"
  exit 6
fi

echo "Done."
exit 0