import sys
import string
import os.path
from whrandom import choice


#---------------------------------------------------------------------
#  def: print IBM Copyright
#---------------------------------------------------------------------
def printCopyright():
   print """
      ***************************************************************
      Licensed Materials - Property of IBM
      5724-O05
      (c) Copyright IBM Corp. 2006, 2008 All Rights Reserved.
      Trademark of International Business Machines
      ***************************************************************
   
   """
#endDef printCopyright

#-----------------------------
# usage output
#-----------------------------
def printUsage():
   print """
   
      Syntax: ./wsadmin -lang jython -f xdmsMessaging.py <-create|-destroy>
	  {-cluster <cluster_name> | -node <node> -server <server>}
	  {-busDataSourceJndi <jndiName> | -useBusFileStore [-fileStoreBaseDir <dir>]}
	  [-busName <busName>]
 
	  create - flag to create the JMS artifacts
	  destroy - flag to remove the JMS artifacts
          node - node name
	  server - server name (must be accompanied by the node argument)
	  cluster - cluster name
	  busDataSourceJndi - JNDI name for the datasource
	  useBusFileStore - flag to create a filestore
	  fileStoreBaseDir - directory to hold the filestore data
	  busName - name of the bus to create or destroy
	  ear - the path to the ear file
	  app - display name for the application
	  wasHome - path to the root directory of the WebSphere installation
	  

      Example:
         ./wsadmin.sh -lang jython -f xdmsMessaging.py -create 
		 -cluster SharedListCluster -busDataSourceJndi jdbc/xdmssib
		 
		 ./wsadmin.sh -lang jython -f xdmsMessaging.py -destroy
		 -cluster SharedListCluster

   """

#-----------------------------------------------------------------
# Helpers
#-----------------------------------------------------------------
def exception(excep, retCode):
   sys.stderr.write('An exception occurred: '+excep+'\n')
   if( retCode > 0 ):
      sys.exit(retCode)
#endDef exception

def saveAndSync():
   sys.stdout.write('Saving configuration changes.\n')
   AdminConfig.save()
   sys.stdout.write('Configuration was successfully saved.\n')
   #AdminConfig.sync()
   #sys.exit(0)
#endDef saveAndSync
	

#############################################################################
# Generate a unique schema name for a bus member datasource.
#
# The default is to have the form:  XDMS_nodename_servername.  If this string is 
# over 30 characters long, just return the last 30 characters
#
# This function can be modified to return a different format
#############################################################################
def generateSchemaName(busName, nodeName, serverName):
	schemaName = "XDMS" + "_" + nodeName + "_" + serverName
	if (len(schemaName) > 30):
		rand = randomStr()
		schemaName = schemaName[0:25]+"_"+rand
	return schemaName
#endDef

#############################################################################
# Generate a random sequence of characters
#
# Supply a positive integer parameter to receieve a string of a given
# length.  Otherwise, the function will return a string of length 4.
#
#############################################################################
def randomStr(length=4):
   if(length < 1):
      length=4;
   return ''.join([choice(string.letters) for i in range(length)])
#endDef

# Takes in a list from a WSAdmin object and creates a Jython list out of it
def wsadminToList(inStr):
   outList=[]
   if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
      tmpList = inStr[1:-1].split(" ")
   else:
      tmpList = inStr.split("\n")  #splits for Windows or Linux
   for item in tmpList:
      item = item.rstrip();        #removes any Windows "\r"
      if (len(item)>0):
         outList.append(item)
   return outList
#endDef

# Strips out the []'s and the specified string
def stripOutStringAndBrackets(string, value):
   retVal = string.replace('[' + value, '')
   retVal = retVal.replace(']', '')
   retVal = retVal.strip()
   return retVal
#endDef

#-----------------------------------------------------------------
# Functions
#-----------------------------------------------------------------

# Get a list of members of a cluster
def getClusterMembers(clusterName):
   # get the cluster id
   cluster = AdminConfig.getid("/ServerCluster:" + clusterName + "/")
   membersString = AdminConfig.showAttribute(cluster, "members")
   members = wsadminToList(membersString)
   return members
#endDef


# Returns true (1) if the given cluster name is located
def isValidCluster( clusterParm ):
   global scope
   scope = AdminConfig.getid("/ServerCluster:"+clusterName+"/")
   if len(scope) != 0:
      return 1
   else:
      return 0     
#endDef

# Returns true (1) if the given node name is located
def isValidNode( nodeParm ):
   global scope
   valid = 0
   elementsString = AdminConfig.list('Cell')
    
   if debug:
      sys.stdout.write('elementsString= ' + elementsString + '\n')
   #endIf
        
   elements = wsadminToList(elementsString)
   for element in elements:  

      if debug:
         sys.stdout.write('element= ' + element + '\n')
      #endIf
        
      nodesString = AdminConfig.list('Node')
        
      if debug:
         sys.stdout.write('nodesString= ' + nodesString + '\n')
      #endIf
        
      nodes = wsadminToList(nodesString)
     
      for node in nodes:  
         nodeName = AdminConfig.showAttribute(node, 'name')
            
         if debug:
            sys.stdout.write('node ' + node + ' has name attribute = ' + nodeName + '\n')
         #endIf
             
         if (( nodeName == nodeParm ) ):
            valid = 1
            scope = node
            break 
         #endIf 
      #endFor 
   #endFor
   return valid
 #endDef 

# Returns true (1) if the given server name is located
def isValidServer( serverName ):
   # global debug
   valid = 0
   elementsString = AdminConfig.list('Cell')

   if debug:
      sys.stdout.write('elementsString= ' + elementsString + '\n')
   #endIf
        
   elements = wsadminToList(elementsString)
   for element in elements:  
      if debug:
         sys.stdout.write('element= ' + element + '\n')
      #endIf
        
      serversString = AdminConfig.list('Server')
        
      if debug:
         sys.stdout.write('serversString= ' + serversString + '\n')
      #endIf
        
      servers = wsadminToList(serversString)
     
      for server in servers:  
         srvName = AdminConfig.showAttribute(server, 'name')
          
         if debug:
            sys.stdout.write('server ' + server + ' has name attribute = ' + srvName + '\n')
         #endIf
            
         if (( srvName == serverName) ):
            valid = 1
            break 
         #endIf 
      #endFor 
   #endFor
   return valid
#endDef 

#-----------------------------------------------------------------
# Validation Functions
#-----------------------------------------------------------------
def validate():
   global scopeName
   if create and destroy:
      exception('Cannot create bus and destroy the bus in the same execution', 20)
	
   if ( clusterInstall ):
      scopeName = "cluster " + clusterName
      if ( not ( isValidCluster(clusterName))):
         exception('Cluster "' + clusterName + '" specified was not found on this cell ', 1 )
   else:
      scopeName = "node "+ nodeName
      
      if ( (nodeName == "") or (serverName == "") ):
         printUsage()
         exception('-node and -server are required arguments\n', 4)
      #endIf
      
      if ( not ( isValidNode(nodeName))):
      	 printUsage()
         exception('The specified Node "' + nodeName + '" was not found on this cell', 2 )
      #endIf
      
      if ( not (isValidServer( serverName ))):
      	 printUsage()
         exception('The specified Server "' + serverName + '" was not found on this node', 3 )
      #endIf
   #endIf
   
#endDef validate

#-----------------------------------------------------------------
# Create Functions
#-----------------------------------------------------------------

def createBus(busName, busDesc):
   AdminTask.createSIBus(["-bus", busName, "-description", busDesc, "-secure", "false"] )  
#endDef 

def addBusMemberServer( busName, nodeName, serverName, dataSourceJndi ):
   if debug:
      sys.stdout.write("Adding bus member for nodeName: " + nodeName + ", serverName: " + serverName)

   try:
      if useBusFileStore:
         if debug:
            sys.stdout.write("addBusMemberServerFilestore(" + busName + ", " + nodeName + ", " + serverName + ")")
         
         addBusMemberServerFilestore(busName, nodeName, serverName)
         
      else:
         schemaName = generateSchemaName( busName, nodeName, serverName)
         if debug:
            sys.stdout.write("addBusMemberServerDatastore(" + busName + ", " + nodeName + ", " + serverName + ", " + dataSourceJndi + ", " + schemaName + ")")
         
         addBusMemberServerDatastore(busName, nodeName, serverName, dataSourceJndi, schemaName)
   
   except:
      temp = str(sys.exc_value)
      index = temp.find('CWSJA0003')
      if ( index < 0 ):
         exception( str(sys.exc_value), 16 )
      else:
         sys.stdout.write('    bus member for ' + nodeName + ':' + serverName + ' already exists\n')
      #endIf
#endDef

# Create a filestore bus member with a filestore
def addBusMemberServerFilestore(busName, nodeName, serverName ):
   if (len(fileStoreBaseDir) > 0):
      uniqueDir = nodeName + "." + serverName + "-" + busName
      logDir = os.path.join(fileStoreBaseDir, uniqueDir, "log")
      storeDir = os.path.join(fileStoreBaseDir, uniqueDir, "store")

      if debug:
         sys.stdout.write("  using directories: " + logDir + " (log), " + storeDir + " (permanent and temporary store)")
      #endIf
		
      AdminTask.addSIBusMember(["-bus", busName, "-node", nodeName, "-server", serverName, "-fileStore", \
		                          "-logDirectory", logDir, "-permanentStoreDirectory", storeDir, "-temporaryStoreDirectory", storeDir ] )
   else:
      if debug:
         sys.stdout.write("  using default directories for log, permanent store, and temporary store")
      #endIf
      
      AdminTask.addSIBusMember(["-bus", busName, "-node", nodeName, "-server", serverName, "-fileStore"] )
   #endIf
#endDef 

def addBusMemberServerDatastore(busName, nodeName, serverName, dataSourceJndi, schemaName ):
   AdminTask.addSIBusMember(["-bus", busName, "-node", nodeName, "-server", serverName, "-dataStore", "-datasourceJndiName", dataSourceJndi, "-createDefaultDatasource", "FALSE", "-schemaName", schemaName ] )
#endDef 

# Add all the servers in a cluster as a server bus member
def addClusterServers(busName, clusterName, dataSourceJndi ):
   if debug:
      sys.stdout.write("Adding servers in cluster " + clusterName + " to bus " + busName)
   # get list of members
   members = getClusterMembers(clusterName)
   for member in members:
      nodeName = AdminConfig.showAttribute(member, "nodeName")
      serverName = AdminConfig.showAttribute(member, "memberName")
      addBusMemberServer(busName, nodeName, serverName, dataSourceJndi)
   #endFor
#endDef

def addBusMemberCluster(busName, clusterName, busDataSourceJndi, schemaName ):
   sys.stdout.write('schemaName = ' + schemaName + '.\n')
   if (len(schemaName)>0):
      if debug:
          sys.stdout.write('AdminTask.addSIBusMember(-bus, ' + busName + ' -cluster, ' + clusterName + ', -dataStore, -datasourceJndiName, ' + busDataSourceJndi + ', -schemaName, ' + schemaName + ')\n')
      #endIf
      AdminTask.addSIBusMember(["-bus", busName, "-cluster", clusterName, "-dataStore", "-datasourceJndiName", busDataSourceJndi, "-schemaName", schemaName ] )
   else:
      if debug:
         sys.stdout.write('AdminTask.addSIBusMember(-bus, ' + busName + ' -cluster, ' + clusterName + ', -dataStore, -datasourceJndiName, ' + busDataSourceJndi + ')\n')
      #endIf
      AdminTask.addSIBusMember(["-bus", busName, "-cluster", clusterName, "-dataStore", "-datasourceJndiName", busDataSourceJndi] )
#endDef 

def addBusDest(busName, destName ):
   AdminTask.createSIBDestination(["-bus", busName, "-name", destName, "-type", "TopicSpace"])
#endDef 


def createJMSCF(scope, busName, JMSCF_Name, JMSCF_jndiName):
# XDMS requires a ConnectionFactory 
# type parameter - optional 
#  value queue will cause a QueueConnectionFactory to be created
#  value topic will cause a TopicConnectionFactory to be created
#  Not Specified -  will cause a generic ConnectionFactory to be created
   AdminTask.createSIBJMSConnectionFactory(scope, ["-name", JMSCF_Name, "-jndiName", JMSCF_jndiName, "-busName", busName] )     
#endDef 

# busName
# name - name of topic (
# topicString - hierarchy (company/dept/mytopic)
# topicSpace - name of topic space
def createJMSTopic(scope, busName, name, jndiName, topicString, topicSpace):
   AdminTask.createSIBJMSTopic(scope, ["-name", name, "-jndiName", jndiName, "-busName", busName, "-topicName", topicString, "-topicSpace", topicSpace] )
#endDef 

def createJMSQ(scope, busName, destName, name, jndiName, topicSpace):
   AdminTask.createSIBJMSTopic(scope, ["-name", name, "-jndiName", jndiName, "-busName", busName, "-topicName", destName, "-topicSpace", topicSpace] )
#endDef 

def createJMSAS(scope, busName, destJndiName, JMSAS_Name, JMSAS_jndiName):
   AdminTask.createSIBJMSActivationSpec(scope, ["-name", JMSAS_Name, "-jndiName", JMSAS_jndiName, "-busName", busName, "-destinationJndiName", destJndiName, "-destinationType", "Topic"] )
#endDef 


#-----------------------------------------------------------------
# Delete Functions
#-----------------------------------------------------------------


def deleteEntireBus(busName):
   try:
      AdminTask.deleteSIBus(["-bus", busName] )
   except:
      sys.stdout.write('    Bus '+busName+' does not exist to be deleted \n')
      
   
#endDef 

def deleteBusDestination(busName, destName ):
   try:
      AdminTask.deleteSIBDestination(["-bus", busName, "-name", destName] )
   except:
      sys.stdout.write('    SIBus destination '+destName+' does not exist on '+busName+' to be deleted \n')
#endDef 

def removeBusMemberServer(busName, nodeName, serverName ): 
   try:
      AdminTask.removeSIBusMember(["-bus", busName, "-node", nodeName, "-server", serverName] )
   except:
      sys.stdout.write('    Bus member '+serverName+' does not exist on '+busName+' to be deleted \n')
      
#endDef 

def removeBusMemberCluster(busName, clusterName ):
   try:
      AdminTask.removeSIBusMember(["-bus", busName, "-cluster", clusterName] )
   except:
      sys.stdout.write('    Bus member '+clusterName+' does not exist on '+busName+' to be deleted \n')
      
#endDef 
# Delete all the server bus members that are in a cluster
def removeClusterServersBusMembers(busName, clusterName ):
   if debug:
      sys.stdout.write('Removing servers in cluster ' + clusterName + ' from bus ' + busName + '\n')
   
   # get list of members
   members = getClusterMembers(clusterName)
   for member in members:
      nodeName = AdminConfig.showAttribute(member, "nodeName")
      serverName = AdminConfig.showAttribute(member, "memberName")
   
   if debug:
      sys.stdout.write('Removing bus member for nodeName: ' + nodeName + ', serverName: ' + serverName +'\n')
   
   try:
      if debug:
         sys.stdout.write('removeBusMemberServer(' + busName + ', ' + nodeName + ', ' + serverName + ')\n')
      #endIf
      removeBusMemberServer(busName, nodeName, serverName )
   except:
      temp = str(sys.exc_value)
      index = temp.find('already exists')
      if ( index < 0 ):
         exception( str(sys.exec_value), 20)
      else:
         sys.stdout.write('    bus member for ' + nodeName + ':' + serverName + ' already exists\n')
      #endIf
   #endFor
#endDef

def deleteJMSCF(scope, busName, JMSCF_Name, JMSCF_jndiName):
   found = 0
        
   # PXNotify currently requires a QueueConnectionFactory 
   # type parameter - optional 
   #  value queue will list all QueueConnectionFactories
   #  value topic will list all TopicConnectionFactories
   #  Not Specified -  will list all generic ConnectionFactories

   cfsString = AdminTask.listSIBJMSConnectionFactories(scope, [] )

# listSIBJMSConnectionFactories is return a list of J2CConnectionFactory objects instead
# of a list of SIBJMSConnectionFactory objects and therefore the 'busName' attribute is
# not available
        
   if debug:
      sys.stdout.write('cfsString= ' + cfsString + '\n')
   #endIf
        
   cfs = wsadminToList(cfsString)
     
   for cf in cfs:  
      cfName = AdminConfig.showAttribute(cf, 'name')
            
      if debug:
         sys.stdout.write('cf ' + cf + ' has name attribute = ' + cfName + '\n')
      #endIf
             
      if (( cfName == JMSCF_Name) ):
         cfJndiName = AdminConfig.showAttribute(cf, 'jndiName')

         if debug:
            sys.stdout.write('cf ' + cf + ' has jndiName attribute = ' + cfJndiName + '\n')
         #endIf

         if (( cfJndiName == JMSCF_jndiName) ):
            found = 1
            sys.stdout.write('  JMS Connection Factory ' + JMSCF_Name + ' with JNDI Name ' + JMSCF_jndiName + ' on bus ' + busName + ' deleted\n')
            AdminTask.deleteSIBJMSConnectionFactory( cf )
            break
         # endIf
      #endIf 
   #endFor 

   if ( not ( found ) ):
      sys.stdout.write('  JMS Connection Factory ' + JMSCF_Name + ' with JNDI Name ' + JMSCF_jndiName + ' on bus ' + busName + ' does not exists\n')
   #endIf 
#endDef 

def deleteJMSAS(scope, busName, JMSQ_jndiName, JMSAS_Name, JMSAS_jndiName):
   found = 0
   actvSpecsString = AdminTask.listSIBJMSActivationSpecs(scope)

# listSIBJMSConnectionFactories is return a list of J2CConnectionFactory objects instead
# of a list of SIBJMSConnectionFactory objects and therefore the 'busName' attribute is
# not available
        
   if debug:
      sys.stdout.write('actvSpecsString= ' + actvSpecsString + '\n')
   #endIf

   actvSpecs = wsadminToList(actvSpecsString)
     
   for actvSpec in actvSpecs:  
      asName = AdminConfig.showAttribute(actvSpec, 'name')
            
      if debug:
         sys.stdout.write('actvSpec ' + actvSpec + ' has name attribute = ' + asName + '\n')
      #endIf
             
      if (( asName == JMSAS_Name) ):
         asJndiName = AdminConfig.showAttribute(actvSpec, 'jndiName')
         
         if debug:
            sys.stdout.write('actvSpec ' + actvSpec + ' has jndiName attribute = ' + asJndiName + '\n')
         #endIf

         if (( asJndiName == JMSAS_jndiName) ):
            asDestJndiName = AdminConfig.showAttribute(actvSpec, 'destinationJndiName')
                
            if debug:
                sys.stdout.write('actvSpec ' + actvSpec + ' has destinationJndiName attribute = ' + asDestJndiName + '\n')
            #endIf

            if (( asDestJndiName == JMSQ_jndiName) ):
               found = 1
               sys.stdout.write('  JMS Activation Spec ' + JMSAS_Name + ' with JNDI Name ' + JMSAS_jndiName + ' on bus ' + busName + ' deleted\n')
               AdminTask.deleteSIBJMSActivationSpec( actvSpec )
               break
            #endIf
         #endIf 
      #endIf 
   #endFor 

   if ( not ( found ) ):
       sys.stdout.write('  JMS Activation Spec' + JMSAS_Name + ' with JNDI Name ' + JMSAS_jndiName + ' on bus ' + busName + ' does not exists\n')
    #endIf 
#endDef 



def deleteJMSTopic(scope, busName, destName, JMSTopic_Name, JMSTopic_jndiName):
   found = 0
   topicsString = AdminTask.listSIBJMSTopics(scope)

# listSIBJMSTopics returns a list of J2CAdminObject objects instead
# of a list of SIBJMSQueue objects and therefore the 'topicName' attribute is
# not available
   if debug:
       sys.stdout.write('topicsString= ' + topicsString + '\n')
   #endIf 
   topics = wsadminToList(topicsString)

   for topic in topics:  
      topicName = AdminConfig.showAttribute(topic, 'name')
      if debug:
          sys.stdout.write('topic ' + topic + ' has name attribute = ' + topicName + '\n')
      #endIf
             
      if (( topicName == JMSTopic_Name) ):
         topicJndiName = AdminConfig.showAttribute(topic, 'jndiName')
         if debug:
             sys.stdout.write('topic ' + topic + ' has jndiName attribute = ' + topicJndiName + '\n')
         #endIf

         if (( topicJndiName == JMSTopic_jndiName) ):
            # if (( queueName == destName) ):
            found = 1
            sys.stdout.write('  JMS Topic ' + JMSTopic_Name + ' with JNDI Name ' + JMSTopic_jndiName + ' on bus ' + busName + ' deleted\n')
            AdminTask.deleteSIBJMSTopic( topic )
            break
         # endIf
      #endIf 
   #endFor 

   if ( not ( found ) ):
       sys.stdout.write('  JMS Topic ' + JMSTopic_Name + ' with JNDI Name ' + JMSTopic_jndiName + ' on bus ' + busName + ' does not exists\n')
   #endIf 
#endDef 



#-----------------------------------------------------------------
# Major Functions
#-----------------------------------------------------------------

def createSIBus():
   sys.stdout.write('Adding SIBus ' + busName + ' .......\n')
   try:
      createBus(busName, busDesc)
      sys.stdout.write('    ' + busDesc + ' added\n')
   except:
      temp = str(sys.exc_value)
      index = temp.find('CWSJA0000')
      if ( index < 0 ):
         exception( str(sys.exc_value), 16 )
      else:
         sys.stdout.write('    SIBus ' + busName + ' already exists\n')
      #endIf

   if ( clusterInstall ):
      sys.stdout.write('Adding servers in Cluster ' + clusterName + ' as bus members of SIBus ' +busName + ' .......\n')
      try:
         addClusterServers(busName, clusterName, busDataSourceJndi)
         sys.stdout.write('Servers in cluster ' + clusterName + ' added as bus members of SIBus ' +busName + '\n')
      except:
         temp = str(sys.exc_value)
         index = temp.find('already exists')
         if ( index < 0 ):
            exception( str(sys.exc_value), 15 )
         else:
            sys.stdout.write(clusterName + ' already added as a cluster member of SIBus ' +busName + '\n')
         #endIf

   else:
      sys.stdout.write('Adding ' + nodeName + ':' + serverName + ' as a server member of SIBus ' +busName + ' .......\n')
      try:
         addBusMemberServer(busName, nodeName, serverName, busDataSourceJndi)
         sys.stdout.write('    ' + nodeName + ':' + serverName + ' added as a server member of SIBus ' +busName + '\n')
      except:
         temp = str(sys.exc_value)
         index = temp.find('already exists')
         if ( index < 0 ):
            exception( str(sys.exc_value), 14 )
         else:
            sys.stdout.write('    ' + nodeName + ':' + serverName + ' already a server member of bus ' +busName + '\n')
         #endIf
   #endIf	
	
   sys.stdout.write('Adding Destination ' + SipNotifyTopicSpace + ' to SIBus ' +busName + ' .......\n')
    
   try:
      addBusDest(busName, SipNotifyTopicSpace)
      sys.stdout.write('  Destination ' + SipNotifyTopicSpace + ' added to SIBus ' +busName + '\n')
   except:
      temp = str(sys.exc_value)
      index = temp.find('CWSJA0009')
      if ( index < 0 ):
         exception( str(sys.exc_value), 13 )
      else:
         sys.stdout.write('  Destination ' + SipNotifyTopicSpace + ' already added to SIBus ' +busName + '\n')
      #endIf

   sys.stdout.write('Adding JMS Connection Factory ' + JMSCF_Name + ' to Node' +nodeName + ' .......\n')

   try:
      createJMSCF(scope, busName, JMSCF_Name, JMSCF_jndiName)
      sys.stdout.write('    JMS Connection Factory ' + JMSCF_Name + ' added to ' +scopeName + '\n')
   except:
      temp = str(sys.exc_value)
      index = temp.find('ADMG0037')
      index2 = temp.find('CWMSR0074')
      if ( index < 0 and index2 < 0):
         exception( str(sys.exc_value), 12 )
      else:
         sys.stdout.write('    JMS Connection Factory ' + JMSCF_Name + ' already exists on ' +scopeName + '\n')
       #endIf

   sys.stdout.write('Adding JMS Topic ' + SipNotifyTopicName + ' to ' +scopeName + ' .......\n')

   try:
      createJMSTopic(scope, busName, SipNotifyTopicName, SipNotifyJndiName, SipNotifyTopicString, SipNotifyTopicSpace)               
   except:
      temp = str(sys.exc_value)
      index = temp.find('ADMG0037')
      index2 = temp.find('CWMSR0074')
      if ( index < 0 and index2 < 0):
         exception( str(sys.exc_value), 11 )
      else:
         sys.stdout.write('    JMS Topic ' + SipNotifyTopicName + ' already exists on ' +scopeName + '\n')
      #endIf

   sys.stdout.write('Adding JMS Activation Spec ' + JMSAS_Name + ' to ' +scopeName + ' .......\n')

   try:
      createJMSAS(scope, busName, SipNotifyJndiName, JMSAS_Name, JMSAS_jndiName)
      sys.stdout.write('    JMS Activation Spec ' + JMSAS_Name + ' added to ' +scopeName + '\n')
   except:
      temp = str(sys.exc_value)
      index = temp.find('ADMG0037')
      index2 = temp.find('CWMSR0074')
      if ( index < 0 and index2 < 0):
         exception( str(sys.exc_value), 10 )
      else:
         sys.stdout.write('    JMS Activation Spec ' + JMSAS_Name + ' already exists on ' +scopeName + '\n')
      #endIf	
#endDef

def destroySIBus():
   sys.stdout.write('Deleting JMS Activation Spec ' + JMSAS_Name + ' .......\n')
   deleteJMSAS(scope, busName, SipNotifyJndiName, JMSAS_Name, JMSAS_jndiName)

   sys.stdout.write('Deleting JMS Topic ' + SipNotifyTopicName + ' .......\n')
   # deleteJMSQ(scope, busName, destName, JMSQ_Name, JMSQ_jndiName)
   deleteJMSTopic(scope, busName, SipNotifyTopicSpace, SipNotifyTopicName, SipNotifyJndiName)

   sys.stdout.write('Deleting JMS Connection Factory ' + JMSCF_Name + ' .......\n')
   deleteJMSCF(scope, busName, JMSCF_Name, JMSCF_jndiName)

   # Delete Bus members and bus destination
   sys.stdout.write('Deleting bus destination ' + SipNotifyTopicSpace + ' from bus ' + busName + '\n')
   deleteBusDestination( busName, SipNotifyTopicSpace )
	 
   if (clusterInstall):
      # Remove the server bus members that are part of the cluster
      sys.stdout.write('Removing server bus members that are part of cluster ' + clusterName + ' from bus ' + busName +'\n')
      removeClusterServersBusMembers(busName, clusterName )
   else:
      # Remove the server bus member
      sys.stdout.write('Removing server bus member from bus ' + busName + '\n')
      if debug:
         sys.stdout.write('removeBusMemberServer(' + busName + ', "' + nodeName + ', ' + serverName + ')')
      #endIf
      removeBusMemberServer(busName, nodeName, serverName )
   #endIf
   try:
      busMembers = AdminTask.listSIBusMembers(["-bus", busName])
      if( len(busMembers) == 0 ):
         # Removing the bus
         sys.stdout.write('Deleting SIBus ' + busName + ' as no more members exist .......\n')
         try:
            deleteEntireBus(busName)
            sys.stdout.write('SIBus ' + busName + ' was deleted\n')
         except:
            temp = str(sys.exc_value)
            index = temp.find('CWSJA0001')
            if ( index < 0 ):
               exception( str(sys.exc_value) , 8)
            else:
               sys.stdout.write('SIBus ' + busName + ' does not exist\n')
      #endIf
   except:
      temp = str(sys.exc_value)
      index = temp.find('CWSJA0001')
      if ( index < 0 ):
         exception( str(sys.exc_value) , 28)
      else:
         sys.stdout.write('SIBus ' + busName + ' does not exist\n')
#endDef

#-----------------------------------------------------------------
# Main
#-----------------------------------------------------------------

busName = "XDMSBus"
busDesc = "XDMS Service Integration Bus"
JMSCF_Name = "xdmsTCF"
JMSCF_jndiName = "jms/xdmsTCF"
JMSAS_Name = "XDMSActivationSpec"
JMSAS_jndiName = "eis/XDMSActivationSpec"

SipNotifyTopicName = "xdmsPublishT"
SipNotifyTopicString = "XDMS/SIPNotify"
SipNotifyTopicSpace = "SipNotifyTopicSpace"
SipNotifyJndiName = "jms/xdmsPublishT"

wasObj = ""
nodeName = ""
scope = ""
scopeName = ""
serverName = ""
clusterName = ""
fileStore = ""
logDir = ""
permStoreDir = ""
tempStoreDir = ""
debug = 0
clusterInstall = 0
useBusFileStore = 0
fileStoreBaseDir = ""
busDataSourceJndi="jdbc/xdmssib"
destroy = 0
create = 0

printCopyright()

count = 0
arglen = len(sys.argv)
#print 'number of args received= ' + str(arglen) + '\n'

while (count < arglen):
   paramflag = sys.argv[count]
   count = count+1 

   if (cmp(paramflag, "-node") == 0):
      param = sys.argv[count]
      nodeName = param
   elif (cmp(paramflag, "-server") == 0):
      param = sys.argv[count]
      serverName = param
   elif (cmp(paramflag, "-busName") == 0):
      param = sys.argv[count]
      busName = param
   elif (cmp(paramflag, "-busDest") == 0):
      param = sys.argv[count]
      SipNotifyTopicSpace = param
   elif (cmp(paramflag, "-cluster") == 0):
       param = sys.argv[count]
       clusterName = param
       clusterInstall = 1
   elif (cmp(paramflag, "-busDataSourceJndi") == 0):
       param = sys.argv[count]
       busDataSourceJndi = param
   elif (cmp(paramflag, "-useBusFileStore") ==0):
       count = count-1
       useBusFileStore = 1
   elif (cmp(paramflag, "-fileStoreBaseDir") == 0):
       param = sys.argv[count]
       fileStoreBaseDir = param
   elif (cmp(paramflag, "-overrideBusName") == 0):
      param = sys.argv[count]
      busName = param
   elif (cmp(paramflag, "-overrideBusDest") == 0):
      param = sys.argv[count]
      destName = param
   elif (cmp(paramflag, "-create") == 0):
      count = count-1
      create = 1
   elif (cmp(paramflag, "-destroy") == 0):
      count = count-1
      destroy = 1
   elif (cmp(paramflag, "-schemasFile") == 0):
      param = sys.argv[count]
      schemasFile = param
   elif (cmp(paramflag, "debug") == 0):
      count = count-1
      debug = 1
   #endIf 
 
   count = count+1
#endWhile 

# Validate scripting environment
validate()

if ( clusterInstall ):
   sys.stdout.write('Configuring XDMS messaging for cluster ' + clusterName +'\n')
   SipNotifyTopicSpace = clusterName
else:
   sys.stdout.write('Configuring XDMS messaging for server ' + serverName + ' on node ' + nodeName + '\n')
#endIf

if create:
   createSIBus()
      
elif destroy:
   destroySIBus()
   
else:
   exception('No state defined.\n', 5)

#endIf

saveAndSync()

if ( clusterInstall ):
   sys.stdout.write('XDMS messaging configured for cluster ' + clusterName +'\n')
else:
   sys.stdout.write('XDMS messaging configured for server ' + serverName + ' on node ' + nodeName +'\n')
#endIf

sys.stdout.write('Done.\n')
sys.exit(0)
